pub fn add_storage_layout_output<C: Compiler<CompilerContract = Contract>>(
project: &mut Project<C>,
)Expand description
Adds storageLayout to the compiler output selection for the given project.
pub fn add_storage_layout_output<C: Compiler<CompilerContract = Contract>>(
project: &mut Project<C>,
)Adds storageLayout to the compiler output selection for the given project.